clear

*******************************************************************************************************;
*** 																								***			
***								STATA DO FILE FOR REPLICATION OF RESULTS FOR						***
***																									***
***									Madsen, Raschky, and Skali (2015). 								***
***						``Does Democracy Drive Income in the World, 1500-2000?''					***
***									     European Economic Review.									***
***																									***
***										       TABLES 1 - 7											***
***																									***
*** [NOTE 1:  REPLICATION FILE FOR TABLES 8 and 9:	EER-D-14-00083_Estimates_T8_T9]					***	
*** [NOTE 2: Change path where all the file are saved before running this file(see below)]			***
*******************************************************************************************************

capture log close

*cd /*[PATH]*/

use EER-D-14-00083_data_PANEL_1820_2000.dta




***************************************************************************************************************************************************
/*Table 1. Descriptive Statistics.*/
***************************************************************************************************************************************************

 
qui xi: xtreg  lny  l.lny   l.Dem   i.time   if l.DemF!=.         ,  fe r  
sum lny  Dem Lit SecEdu  DemF Death  ResDis if e(sample)==1
tab countryname if e(sample)==1 


***************************************************************************************************************************************************
/*Table 2. OLS income regressions (Eq. (1)).*/
***************************************************************************************************************************************************
 
xi: xtreg  lny  l.lny   l.Dem   i.time    if    murtin_sample==1 & year>=1870  ,  fe cl(countryid) 
estimates store T2_1
xi: xtreg  lny  l.lny   l.Dem   i.time    if    murtin_sample==1       ,  fe cl(countryid) 
estimates store T2_2
xi: xtreg  lny  l.lny   l.Dem   i.time     if    year>1860  & l.DemF!=.    ,  fe cl(countryid) 
estimates store T2_3
xi: xtreg  lny  l.lny   l.Dem   i.time   if l.DemF!=.        ,  fe cl(countryid) 
estimates store T2_4
xi: xtreg  lny  l.lny   l.Dem    i.time    if    murtin_sample!=1      ,  fe cl(countryid) 
estimates store T2_4

 
/*
#delimit;
estout   T2_* 
,   cells(b(star fmt(%9.3f)) se(par))
         stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared))  starlevels(* 0.10 **
0.05 *** 0.01)
          legend label collabels(none) varlabels(_cons Constant)
;
*/


***************************************************************************************************************************************************
/*Table 3. First-stage regressions (Eqs. (2) and (3)). */
***************************************************************************************************************************************************
/*[NOTE:] For results of First stage F-Stat refer to code for Table 4*/


qui xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time  ,   fe  ffirst cl(countryid)
xi: xtreg  l.Dem l.DemF  l.lny       i.time  if e(sample)==1,  fe cl(countryid) 
estimates store T3_1

qui xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if year>=1900  ,   fe  ffirst cl(countryid)
xi: xtreg  l.Dem l.DemF  l.lny       i.time if year>=1900 &  e(sample)==1,  fe cl(countryid) 
estimates store T3_2

qui xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if year>=1950  ,   fe  ffirst cl(countryid)
xi: xtreg  l.Dem l.DemF  l.lny       i.time if year>=1950 &  e(sample)==1,  fe cl(countryid) 
estimates store T3_3

qui xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if year<1990  ,   fe  ffirst cl(countryid)
xi: xtreg  l.Dem l.DemF  l.lny       i.time if year<1990   ,  fe cl(countryid) 
estimates store T3_4

xi: xtreg  l.Dem l.DemF  l.lny   SecEdu    i.time  ,  fe cl(countryid) 
estimates store T3_5

xi: xtreg  l.Dem l.DemF  l.lny   l.Lit     i.time   ,  fe cl(countryid) 
estimates store T3_6

qui xi: xtivreg2 lny  l.lny   (  l.Lit =     l2.MWA_X_CS )   i.time  if l.Dem!=. &  year>1810 ,   fe  ffirst r
xi: xtreg l.Lit  l.lny        l2.MWA_X_CS   i.time  if l.Dem!=. & e(sample)==1,   fe  r 
estimates store T3_7

qui xi: xtivreg2 lny  l.lny   ( l.Dem l.Lit=    l2.MWA_X_CS  l.DemF)   i.time  ,   fe  ffirst  cl(countryid)
xi: xtreg l.Lit  l.lny         l2.MWA_X_CS l.DemF  i.time  if l.Dem!=.& e(sample)==1,   fe  r 
estimates store T3_8

xi: xtreg l.Dem  l.lny          l2.MWA_X_CS l.DemF  i.time  if l.Dem!=. & e(sample)==1,   fe  cl(countryid)
estimates store T3_9

/*
#delimit;
estout  T3_* 
,   cells(b(star fmt(%9.3f)) se(par))
         stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared))  starlevels(* 0.10 **
0.05 *** 0.01)
          legend label collabels(none) varlabels(_cons Constant)
;
*/


***************************************************************************************************************************************************
/*Table 4. 2SLS-FE income regressions (Eq. (1)). */
***************************************************************************************************************************************************


xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time  ,   fe  ffirst cl(countryid)
outreg2 using base_iv.tex, replace tex se drop(_I*) addtext(Dependant, lny, Comment, 0)
estimates store T4_1
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if year>=1900  ,   fe  ffirst cl(countryid)
outreg2 using base_iv.tex, append tex se drop(_I*) addtext(Dependant, lny, Comment, Ex <1900)
estimates store T4_2
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if year>=1950  ,   fe  ffirst cl(countryid)
outreg2 using base_iv.tex, append tex se drop(_I*) addtext(Dependant, lny, Comment, Ex <1950)
estimates store T4_3
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if year<1990  ,   fe  ffirst cl(countryid)
outreg2 using base_iv.tex, append tex se drop(_I*) addtext(Dependant, lny, Comment, Ex <1950)
estimates store T4_4
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)  SecEdu  i.time  ,   fe  ffirst cl(countryid)
outreg2 using base_iv.tex, append tex se drop(_I*) addtext(Dependant, lny, Comment, 0)
estimates store T4_5
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF) l.Lit   i.time   ,   fe  ffirst cl(countryid)
outreg2 using base_iv.tex, append tex se drop(_I*) addtext(Dependant, lny, Comment, 0)
estimates store T4_6
xi: xtivreg2 lny  l.lny   (  l.Lit =     l2.MWA_X_CS )   i.time  if l.Dem!=. &  year>1810 ,   fe  ffirst cl(countryid)
estimates store T4_7
xi: xtivreg2 lny  l.lny   ( l.Dem l.Lit=    l2.MWA_X_CS  l.DemF)   i.time  ,   fe  ffirst  cl(countryid)
estimates store T4_8

xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.time if    murtin_sample!=1   ,   fe  ffirst cl(countryid)

/*
#delimit;
estout  T4_* 
,   cells(b(star fmt(%9.3f)) se(par))
         stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared))  starlevels(* 0.10 **
0.05 *** 0.01)
          legend label collabels(none) varlabels(_cons Constant)
;
*/



***************************************************************************************************************************************************
/*Table 5. Robustness tests, per capita income regressions (Eq. (1)).*/
***************************************************************************************************************************************************

gen continent=1 if africa==1
replace continent=2 if asia==1
replace continent=3 if europe==1
replace continent=4 if americas==1
replace continent=2 if countryname=="Australia" | countryname=="New Zealand"
replace continent=4 if countryname=="United States" | countryname=="Canada"
 

egen continentyear=group(continent time)

xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    i.continentyear  ,   fe  ffirst cl(countryid)
estimates store T5_1
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF) l.Lit   i.continentyear  ,   fe  ffirst cl(countryid)
estimates store T5_2
xi: xtivreg2 lny  l.lny l.DTF (l.Dem l.Dem_DTF=   l.DemF l.DemF_DTF)    i.time ,   fe  ffirst cl(countryid)
estimates store T5_3
xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF) l.Lit     ,   fe  ffirst cl(countryid)
estimates store T5_4
xi: ivreg2 lny  l.lny  (l.Dem=    l.DemF) l.Lit   i.time   ,     ffirst r
estimates store T5_5

xi: xtreg  l.Dem      l.DemF  i.time    if l.lny!=. & l.Lit !=.     ,  fe cl(countryid)  
predict yhat
test l.DemF

xi: xtreg  lny  l.lny    yhat  l.Lit i.time    if l.Dem !=.   ,  fe cl(countryid)  
estimates store T5_6
xi: xtivreg lny  l.lny  (l.Dem=    l.DemF)    i.time  ,   re    
estimates store T5_7
xi: xtivreg2 lny    (l.Dem=    l.DemF)    i.time if  l.lny!=. ,   fe   cl(countryid) ffirst
estimates store T5_8
xi: xtivreg2 lny  l.lny   (Dem=    DemF)    i.time ,   fe   cl(countryid) ffirst
estimates store T5_9
xi: xtivreg2 lny    (Dem=    DemF)    i.time if  l.lny!=. ,   fe   cl(countryid) ffirst
estimates store T5_10

/*
#delimit;
estout  T5_* 
,   cells(b(star fmt(%9.3f)) se(par))
         stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared))  starlevels(* 0.10 **
0.05 *** 0.01)
          legend label collabels(none) varlabels(_cons Constant)
;
*/


***************************************************************************************************************************************************
/*Table 6. Robustness tests, per capita income regressions (Eq. (1)). */
***************************************************************************************************************************************************


xi: xtivreg2 lny  l.lny  (l.Dem=    l.GenDistDem)    i.time  ,   fe  ffirst cl(countryid)
estimates store T6_1
 xi: xtreg l.Dem  l.lny     l.GenDistDem      i.time  ,   fe cl(countryid)
 
 xi: xtivreg2 lny  l.lny  (l.Dem=    l.ResDis)      i.time  ,   fe  ffirst cl(countryid)
estimates store T6_2
 xi: xtreg l.Dem  l.lny     l.ResDis      i.time  ,   fe cl(countryid)
  
 xi: xtivreg2 lny  l.lny  (l.Dem=  l.DemF  l.ResDis)      i.time  ,   fe  ffirst  cl(countryid)
 estimates store T6_3

 xi: xtreg l.Dem  l.lny  l.DemF   l.ResDis      i.time  ,   fe  cl(countryid)

xi: xtivreg2 lny  l.lny  (l.Dem=   l.DemF  l.Death )    i.time  ,   fe  ffirst cl(countryid)
estimates store T6_4

xi: xtabond2 lny  l.lny  l.Dem i.time, gmm(L.(lny  Dem), lag (4 4) ) iv(i.time l.DemF)   robust small
estimates store T6_5
xi: xtabond2 lny  l.lny  l.Dem i.time, gmm(L.(lny  Dem), lag (4 4) ) iv(i.time l.DemF l.Death )   robust small nol
estimates store T6_6
xi: xtabond2 lny  l.lny  l.Dem l.Lit i.time, gmm(L.(lny  Dem Lit ), lag (4 4) ) iv(i.time l.DemF  l.Death )   robust small
estimates store T6_7

/*
#delimit;
estout  T6_* 
,   cells(b(star fmt(%9.3f)) se(par))
         stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared))  starlevels(* 0.10 **
0.05 *** 0.01)
          legend label collabels(none) varlabels(_cons Constant)
;
*/



***************************************************************************************************************************************************
/*Table 7. Alternative outcome variables, country specific time trends, and extended specifications.  */
***************************************************************************************************************************************************



xi: xtivreg2  TFP  l.TFP  (l.Dem=    l.DemF)    i.time  ,   fe  ffirst cl(countryid)
estimates store T7_1

xi: xtivreg2  TFP  l.TFP  (l.Dem=    l.DemF)  l.Lit  i.time  ,   fe  ffirst cl(countryid)
estimates store T7_2
 
xi: xtivreg2  d.TFP  ld.TFP  (l.Dem=    l.DemF)    i.time  ,   fe  ffirst cl(countryid)
 estimates store T7_3
 /*R2 as the ratio of model SS over total SS*/
 /*18.72 / (18.72+22.68) = 0.452*/
 

xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF) Lit  KL  i.time  ,   fe  ffirst cl(countryname)
estimates store T7_4

 
/*country-specific timetrend*/

tab countryname, gen(countrydummy)

 foreach var of varlist    countrydummy*   {
 gen `var'_trend =  `var' * (year-1800)
} 


xi: xtivreg2 lny  l.lny  (l.Dem=    l.DemF)    *_trend ,   fe  ffirst cl(countryid)
estimates store T7_5



/*Different measures for democracy*/

gen democ_1=0 if polity2!=.
replace democ_1=1 if polity2>0 & polity2!=.

gen democ_2=0 if polity2!=.
replace democ_2=1 if polity2>5 & polity2!=.

gen democ_3=0 if polity2!=.
replace democ_3=1 if polity2>=8 & polity2!=.
 
gen democchange=d.polity2

xi: xtivreg2 lny  l.lny  (l.democ_1=    l.DemF)  i.time  ,   fe  ffirst cl(countryname)
estimates store T7_6

xi: xtivreg2 lny  l.lny  (l.democ_2=    l.DemF)  i.time  ,   fe  ffirst cl(countryname)
estimates store T7_7

xi: xtivreg2 d.lny  ld.lny  (l.Dem=    l.DemF)    i.time  ,   fe  ffirst cl(countryid)
estimates store T7_8
 
xi: xtivreg2 d.lny  l(1/3).lny  l(1/3)d.lny  (l.Dem=    l.DemF)    i.time  ,   fe  ffirst cl(countryname)
estimates store T7_9
 /*R2 as the ratio of model SS over total SS*/
 /*42.95 / (42.95+44.52) = 0.491*/
  
  
lincom _b[L.lny] + _b[L2.lny] + _b[L3.lny]
lincom   _b[L3d.lny]
  
 

/* 
#delimit;
estout  T7_*
,   cells(b(star fmt(%9.3f)) se(par))
         stats(r2_a N, fmt(%9.3f %9.0g) labels(R-squared))  starlevels(* 0.10 **
0.05 *** 0.01)
          legend label collabels(none) varlabels(_cons Constant)
;
*/
 